@@ -106,17 +106,18 @@ Dashboard::Dashboard(ParleyMainWindow *parent)
 
     GradeReferenceWidget *gradeReferenceWidget = new GradeReferenceWidget();
     gradeReferenceWidget->setMinimumSize(m_widget->width(), 50);
-    m_ui->gridLayout->addWidget(gradeReferenceWidget, 2, 0, 1, ROWSIZE, Qt::AlignCenter);
+    m_ui->gridLayout->addWidget(gradeReferenceWidget, 1, 0, 1, ROWSIZE, Qt::AlignCenter);
 
     m_subGridLayout = new QGridLayout();
     m_subGridLayout->setHorizontalSpacing(50);
     m_subGridLayout->setVerticalSpacing(30);
-    m_ui->gridLayout->addLayout(m_subGridLayout, 5, 0, 1, 4);
+    m_ui->gridLayout_2->addLayout(m_subGridLayout, 2, 0, 1, 1);
+
 
     m_completedGridLayout = new QGridLayout();
     m_completedGridLayout->setHorizontalSpacing(50);
     m_completedGridLayout->setVerticalSpacing(30);
-    m_ui->gridLayout->addLayout(m_completedGridLayout, 9, 0, 1, 4);
+    m_ui->gridLayout_2->addLayout(m_completedGridLayout, 6, 0, 1, 1);
 
     populateMap();
     populateGrid();
@@ -130,9 +131,9 @@ Dashboard::Dashboard(ParleyMainWindow *parent)
     // Signals FROM the signal mappers.  The ones TO the signal mappers are
     // handled below.
     connect(m_practiceSignalMapper, SIGNAL(mapped(const QString &)),
-	    this,                   SLOT(slotPracticeButtonClicked(const QString &)));
+            this,                   SLOT(slotPracticeButtonClicked(const QString &)));
     connect(m_removeSignalMapper,   SIGNAL(mapped(const QString &)),
-	    this,                   SLOT(slotRemoveButtonClicked(const QString &)));
+            this,                   SLOT(slotRemoveButtonClicked(const QString &)));
 
     KConfigGroup cfg(KSharedConfig::openConfig("parleyrc"), objectName());
     applyMainWindowSettings(cfg);
@@ -144,7 +145,7 @@ Dashboard::Dashboard(ParleyMainWindow *parent)
     setTheme();
 
     connect(m_themedBackgroundRenderer, SIGNAL(backgroundChanged(QPixmap)),
-	    this,                       SLOT(backgroundChanged(QPixmap)));
+            this,                       SLOT(backgroundChanged(QPixmap)));
     connect(m_widget, SIGNAL(sizeChanged()), this, SLOT(updateBackground()));
 
     QAction *updateAction = new QAction(this);
@@ -164,11 +165,11 @@ Dashboard::~Dashboard()
 void Dashboard::clearGrid()
 {
    remove(m_subGridLayout,
-     m_subGridLayout->rowCount() - 1, m_subGridLayout->columnCount() - 1,
-     true);
+          m_subGridLayout->rowCount() - 1, m_subGridLayout->columnCount() - 1,
+          true);
    remove(m_completedGridLayout,
-     m_completedGridLayout->rowCount() - 1, m_completedGridLayout->columnCount() - 1,
-     true);
+          m_completedGridLayout->rowCount() - 1, m_completedGridLayout->columnCount() - 1,
+          true);
 }
 
 /**
@@ -229,15 +230,15 @@ void Dashboard::populateGrid()
         QString urlString   = it.key();
         QString titleString = it.value();
 
-	QUrl  url(QUrl::fromLocalFile(urlString));
-	Collection *collection = new Collection(&url, this);
-	collection->close(); // We just want to look at it, not own it, so release the lock.
+        QUrl  url(QUrl::fromLocalFile(urlString));
+        Collection *collection = new Collection(&url, this);
+        collection->close(); // We just want to look at it, not own it, so release the lock.
 
-	// Automatically initialized.
-	DueWords due;
+        WordCount dueWords;
+	int percentageCompleted = dueWords.percentageCompleted();
 
         m_urlArray[k] = url;
-        if (due.percentageCompleted != 100) {
+        if (percentageCompleted != 100) {
             if (j % ROWSIZE == 0) {
                 m_subGridLayout->addItem(new QSpacerItem(50, 1), j / ROWSIZE, 0);
                 j++;
@@ -250,16 +251,16 @@ void Dashboard::populateGrid()
             }
         }
 
-	//QWidget* backWidget = new CollectionWidget(collection, &due, this);
-	CollectionWidget* backWidget = new CollectionWidget(collection, &due, this);
-	m_collectionWidgets.append(backWidget);
-
-        if (due.percentageCompleted != 100) {
+        CollectionWidget* backWidget = new CollectionWidget(collection, &dueWords, this);
+        m_collectionWidgets.append(backWidget);
+        if (percentageCompleted != 100) {
                 backWidget->setFixedSize(COLLWIDTH, COLLHEIGHT1);
+                backWidget->setMinimumSize(COLLWIDTH, COLLHEIGHT1);
                 m_subGridLayout->addWidget(backWidget, j / ROWSIZE, j % ROWSIZE);
         }
         else {
                 backWidget->setFixedSize(COLLWIDTH, COLLHEIGHT2);
+                backWidget->setMinimumSize(COLLWIDTH, COLLHEIGHT2);
                 m_completedGridLayout->addWidget(backWidget, jc / ROWSIZE, jc % ROWSIZE);
         }
 
@@ -268,7 +269,7 @@ void Dashboard::populateGrid()
         m_removeSignalMapper->setMapping(backWidget, urlString);
         connect(backWidget, SIGNAL(removeButtonClicked()), m_removeSignalMapper, SLOT(map()));
 
-        if (due.percentageCompleted != 100) {
+        if (percentageCompleted != 100) {
             j++;
         }
         else {
@@ -281,11 +282,11 @@ void Dashboard::populateGrid()
 
     m_count = k;
     m_completedGridLayout->addItem(new QSpacerItem(50, 1,
-                     QSizePolicy::Expanding, QSizePolicy::Fixed),
-               m_completedGridLayout->rowCount() - 1,
-               m_completedGridLayout->columnCount());
+                                                   QSizePolicy::Expanding, QSizePolicy::Fixed),
+                                   m_completedGridLayout->rowCount() - 1,
+                                   m_completedGridLayout->columnCount());
     m_subGridLayout->addItem(new QSpacerItem(50,1,QSizePolicy::Expanding, QSizePolicy::Fixed),
-              m_subGridLayout->rowCount() - 1, m_subGridLayout->columnCount());
+                             m_subGridLayout->rowCount() - 1, m_subGridLayout->columnCount());
     if (k - kc) {
         m_ui->recentLabel->setText(i18n("Active Collections"));
     } else {
@@ -341,8 +342,8 @@ void Dashboard::slotRemoveButtonClicked(const QString& urlString)
 
     QMessageBox::StandardButton reply;
     reply = QMessageBox::question(this, i18n("Remove"),
-              i18n("Are you sure you want to remove this collection?"),
-              QMessageBox::Yes | QMessageBox::No);
+                                  i18n("Are you sure you want to remove this collection?"),
+                                  QMessageBox::Yes | QMessageBox::No);
     if (reply == QMessageBox::Yes) {
         m_recentFilesMap.remove(urlString);
         m_mainWindow->removeRecentFile(QUrl::fromLocalFile(urlString ));
@@ -380,7 +381,7 @@ void Dashboard::setTheme()
 void Dashboard::updateWidgets()
 {
     foreach (CollectionWidget *cw, m_collectionWidgets) {
-	cw->updateDue();
+        cw->updateDue();
     }
 }
 void Dashboard::updateFontColors()
@@ -397,10 +398,6 @@ void Dashboard::updateBackground()
 {
     m_themedBackgroundRenderer->clearRects();
     m_themedBackgroundRenderer->addRect("startbackground", QRect(QPoint(), m_widget->size()));
-    QRect headerRect = m_ui->headingLabel->frameGeometry();
-    headerRect.setBottom(m_ui->recentFiles->frameGeometry().top() - 1);
-    m_themedBackgroundRenderer->addRect("startheader", headerRect);
-    m_themedBackgroundRenderer->addRect("recentfiles", m_ui->recentFiles->frameGeometry());
     QPixmap pixmap = m_themedBackgroundRenderer->getScaledBackground();
     if (!pixmap.isNull()) {
         m_widget->setPixmap(pixmap);
